Port Status

| Port | Port Description | Port Status | Speed | Linked Speed | Flow Control | Max MTU
| 1 | E SHOP Uplink (MAIN) | Up | Auto | 5G Full | Disable | 9216
| 2 | Living Room | Up | Auto | 2.5G Full | Disable | 9216
| 3 |  | Down | Auto | No Speed | Disable | 9216
| 4 | Mediaserver | Up | Auto | 10G Full | Disable | 9216
| 5 | N SHOP Uplink | Up | Auto | 1000M Full | Disable | 9216
| 6 |  | Down | Auto | No Speed | Disable | 9216
| 7 |  | Down | Auto | No Speed | Disable | 9216
| 8 | Dell iDRAC | Up | Auto | 1000M Full | Disable | 9216
| 9 | Alexander | Up | Auto | 2.5G Full | Disable | 9216
| 10 |  | Down | Auto | No Speed | Disable | 9216
| 11 |  | Up | Auto | 100M Full | Disable | 9216
| 12 | Router Uplink (MAIN) | Up | Auto | 10G Full | Disable | 9216